@@ -14,7 +14,7 @@ import (
 )
 
 // Version is a version number.
-var version = "0.6.8"
+var version = "0.7.2"
 
 // UI is a user interface which is a global variable for mocking.
 var UI cli.Ui
@@ -93,6 +93,11 @@ func initCommands() map[string]cli.CommandFactory {
 				Meta: meta,
 			}, nil
 		},
+		"lock": func() (cli.Command, error) {
+			return &command.LockCommand{
+				Meta: meta,
+			}, nil
+		},
 		"release": func() (cli.Command, error) {
 			return &command.ReleaseCommand{
 				Meta: meta,
