@@ -7,16 +7,25 @@ import (
 
 // Option is a set of parameters to update.
 type Option struct {
-	// A type of updater. Valid value is terraform or provider.
+	// A type of updater. Valid values are as follows:
+	// - terraform
+	// - provider
+	// - module
+	// - lock
 	updateType string
 
 	// If an updateType is terraform, there is no meaning.
-	// If an updateType is provider, Set a name of provider.
+	// If an updateType is provider or module, Set a name of provider or module.
 	name string
 
 	// a new version constraint
 	version string
 
+	// platforms is a list of target platforms to generate hash values.
+	// Target platform names consist of an operating system and a CPU
+	// architecture such as darwin_arm64.
+	platforms []string
+
 	// If a recursive flag is true, it checks and updates directories recursively.
 	recursive bool
 
@@ -25,7 +34,7 @@ type Option struct {
 }
 
 // NewOption returns an option.
-func NewOption(updateType string, name string, version string, recursive bool, ignorePaths []string) (Option, error) {
+func NewOption(updateType string, name string, version string, platforms []string, recursive bool, ignorePaths []string) (Option, error) {
 	regexps := make([]*regexp.Regexp, 0, len(ignorePaths))
 	for _, ignorePath := range ignorePaths {
 		if len(ignorePath) == 0 {
@@ -43,6 +52,7 @@ func NewOption(updateType string, name string, version string, recursive bool, i
 		updateType:  updateType,
 		name:        name,
 		version:     version,
+		platforms:   platforms,
 		recursive:   recursive,
 		ignorePaths: regexps,
 	}, nil
