@@ -1,7 +1,9 @@
 package tfupdate
 
 import (
+	"context"
 	"fmt"
+	"path/filepath"
 
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/hcl/v2/hclsyntax"
@@ -34,7 +36,12 @@ func NewProviderUpdater(name string, version string) (Updater, error) {
 
 // Update updates the provider version constraint.
 // Note that this method will rewrite the AST passed as an argument.
-func (u *ProviderUpdater) Update(f *hclwrite.File) error {
+func (u *ProviderUpdater) Update(_ context.Context, _ *ModuleContext, filename string, f *hclwrite.File) error {
+	if filepath.Base(filename) == ".terraform.lock.hcl" {
+		// skip a lock file.
+		return nil
+	}
+
 	if err := u.updateTerraformBlock(f); err != nil {
 		return err
 	}
